package com.tecit.tbarcode.samples;

import java.io.File;

import com.tecit.jni.barcode.BarcodeType;
import com.tecit.jni.barcode.ColorMode;
import com.tecit.jni.barcode.ImageType;
import com.tecit.jni.barcode.License;
import com.tecit.jni.barcode.TBarCode;
import com.tecit.jni.barcode.TBarCodeException;

public class DemoBarCode
{
	private License license;
  private TBarCode tbc;
  private int btype;
  private double widthMM;
  private double heightMM;
  private double dpi;
  private String data;
  private boolean above;
  private String fontName;
  private int fontSize;
  private double textdistMM; 
  private double notchheightMM;
  private double modulewidthMM;
  private int colormode;
  
  public static void main(String[] args)
	{
		DemoBarCode demo = null;
  	
		try {
			demo = new DemoBarCode();
			
			File licenseFile = new File(System.getProperty("user.home")+File.separator+"license.ini");
			if( licenseFile.exists() && licenseFile.canRead() )
				demo.license = new License(licenseFile);
			else
				System.err.println("No license file "+licenseFile);
			
		  demo.btype = BarcodeType.EAN13;
		  demo.widthMM = 31.350;
		  demo.heightMM = 11.3;
		  demo.dpi = 2540;
		  demo.data = "400724953113";
		  demo.above = true; // -text=below
		  demo.fontName = "Arial";
		  demo.fontSize = 9;
		  demo.textdistMM = -0.2; 
		  demo.notchheightMM = 2;
		  demo.modulewidthMM = 0.33;
		  demo.colormode = ColorMode.CMYK;
			demo.generate();
		}
		catch(Throwable ex){
			ex.printStackTrace();
		}
		finally {
			if( demo!=null )
				demo.dispose();
		}
	}
	
  public DemoBarCode()
  throws Exception
  {
		// create the TBarCode object
		this.tbc = TBarCode.create();
  }
  
  public void dispose()
  {
    // free the bar code handle
    try {
      if( this.tbc!=null )
      	this.tbc.dispose();
    } 
    catch (TBarCodeException ex){
			ex.printStackTrace();
    }
  }
  
	public void generate()
  throws Exception
	{
	  if( this.license!=null )
	  	tbc.licenseMe(this.license);
	  
	  tbc.setBarcodeType(this.btype);
	  tbc.setDpi(this.dpi);
	  tbc.setShowTextAbove(this.above);
	  tbc.setText(this.data);
	  tbc.setTextDistance((int)(this.textdistMM*1000));
	  tbc.setFont(this.fontName, this.fontSize, false);
	  tbc.setNotchHeight((int)(this.notchheightMM*1000));
	  tbc.setModuleWidth((int)(this.modulewidthMM*1000));
	  tbc.setColorMode(this.colormode);
	  
	  // NOTE: 1 inch = 2.54 centimeters
	  int pxHeigth = mmToPixels(this.heightMM, this.dpi);
	  int pxWidth = mmToPixels(this.widthMM, this.dpi);
	  tbc.saveImage("demo.bmp", ImageType.BMP, pxHeigth, pxWidth, TBarCode.getDefaultQuality(ImageType.BMP));
	  tbc.saveImage("demo.gif", ImageType.GIF, pxHeigth, pxWidth, TBarCode.getDefaultQuality(ImageType.GIF));
	  tbc.saveImage("demo.jpg", ImageType.JPG, pxHeigth, pxWidth, TBarCode.getDefaultQuality(ImageType.JPG));
	  tbc.saveImage("demo.png", ImageType.PNG, pxHeigth, pxWidth, TBarCode.getDefaultQuality(ImageType.PNG));
	  tbc.saveImage("demo.tif", ImageType.TIF, pxHeigth, pxWidth, TBarCode.getDefaultQuality(ImageType.TIF));
	  tbc.saveImage("demo.eps", ImageType.EPS, pxHeigth, pxWidth, TBarCode.getDefaultQuality(ImageType.EPS));
	}
	
	public static int mmToPixels(double mm, double dpi)
	{
		return (int)((mm*dpi)/25.4);
	}
}
